==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property text The text of a description for a column.
 */
public data class DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs(
    public val text: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs> {
    override fun toJava():
        com.pulumi.aws.quicksight.inputs.DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs =
        com.pulumi.aws.quicksight.inputs.DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs.builder()
            .text(text?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs].
 */
@PulumiTagMarker
public class DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgsBuilder
internal constructor() {
    private var text: Output<String>? = null

    /**
     * @param value The text of a description for a column.
     */
    @JvmName("roblmvqnbuebviku")
    public suspend fun text(`value`: Output<String>) {
        this.text = value
    }

    /**
     * @param value The text of a description for a column.
     */
    @JvmName("ngikycrgmdxngcms")
    public suspend fun text(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.text = mapped
    }

    internal fun build():
        DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs =
        DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs(
            text = text,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property text The text of a description for a column.
 */
public data class DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs(
    public val text: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs =
        com.pulumi.aws.quicksight.inputs.DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs.builder()
            .text(text?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs].
 */
@PulumiTagMarker
public class DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgsBuilder
internal constructor() {
    private var text: Output<String>? = null

    /**
     * @param value The text of a description for a column.
     */
    @JvmName("vyenqurxlortgwie")
    public suspend fun text(`value`: Output<String>) {
        this.text = value
    }

    /**
     * @param value The text of a description for a column.
     */
    @JvmName("ornidweskwsownsc")
    public suspend fun text(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.text = mapped
    }

    internal fun build(): DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs =
        DataSetLogicalTableMapDataTransformTagColumnOperationTagColumnDescriptionArgs(
            text = text,
        )
}
